@@ -10,7 +10,7 @@
 @Desc    :   用于快捷导入常用的包，注意这个文件不要格式化！
 """
 
-__version__ = "0.2.4"
+__version__ = "0.2.5"
 
 
 # #######################################################
@@ -33,12 +33,15 @@ from gitopenlib.utils import files as gf
 from gitopenlib.utils import others as go
 from gitopenlib.utils import plot as gp
 from gitopenlib.utils import wonders as gw
+from gitopenlib.utils import crawler as gc
 
 # ## 其他常用的包
 import os
 import time
 import sys
 from collections import defaultdict
+from tqdm import tqdm
+import traceback
 
 # ## 科学计算常用包
 import pandas as pd
